@@ -144,7 +144,6 @@ var profileStart;
 
 var enabledDebugger = false;
 var reportNextError = false;
-var breakOnNextError = false;
 var errorInfo = null;
 
 var timer = Timer.createInstance(nsITimer);
@@ -261,8 +260,6 @@ FirebugService.prototype =
         }
 
         jsd = null;
-        if (!jsd)
-            FBTrace.sysout("*********************** SHUTDOWN JSD NULL ");
     },
 
     // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
@@ -919,9 +916,9 @@ FirebugService.prototype =
         return fbs.pauseDepth;
     },
 
-    unPause: function()
+    unPause: function(force)
     {
-        if (fbs.pauseDepth > 0)
+        if (fbs.pauseDepth > 0 || force)
         {
             fbs.pauseDepth--;
             fbs.hookScripts();
@@ -1039,9 +1036,14 @@ FirebugService.prototype =
     onDebug: function(frame, type, rv)
     {
         if ( isFilteredURL(frame.script.fileName) )
+        {
+            reportNextError = false;
             return RETURN_CONTINUE;
+        }
+
         try
         {
+            var breakOnNextError = this.needToBreakForError(reportNextError);
             var debuggr = (reportNextError || breakOnNextError) ? this.findDebugger(frame) : null;
 
             if (reportNextError)
@@ -1214,15 +1216,8 @@ FirebugService.prototype =
             return true;
         }
 
-        if (this.showStackTrace)
-        {
-            reportNextError = true;
-            return false; // Drop into onDebug, sometimes only
-        }
-        else
-        {
-            return !this.needToBreakForError(fileName, lineNo);
-        }
+        reportNextError = { fileName: fileName, lineNo: lineNo };
+        return false; // Drop into onDebug, sometimes only
     },
 
     // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
@@ -2046,10 +2041,9 @@ FirebugService.prototype =
         return returned;
     },
 
-    needToBreakForError: function(fileName, lineNo)
+    needToBreakForError: function(reportNextError)
     {
-        return breakOnNextError =
-            this.breakOnErrors || this.findErrorBreakpoint(this.normalizeURL(fileName), lineNo) != -1;
+        return this.breakOnErrors || this.findErrorBreakpoint(this.normalizeURL(reportNextError.fileName), reportNextError.lineNo) != -1;
     },
 
     startStepping: function()
