@@ -632,8 +632,6 @@ Firebug.ConsolePanel.prototype = extend(Firebug.ActivablePanel,
 
     destroy: function(state)
     {
-        Firebug.ActivablePanel.destroy.apply(this, arguments);
-
         if (this.panelNode.offsetHeight)
             this.wasScrolledToBottom = isScrolledToBottom(this.panelNode);
 
@@ -647,6 +645,7 @@ Firebug.ConsolePanel.prototype = extend(Firebug.ActivablePanel,
             state.profileRow = this.context.profileRow;
         }
 
+        Firebug.ActivablePanel.destroy.apply(this, arguments);  // must be called last
     },
 
     shouldBreakOnNext: function()
