@@ -7,6 +7,7 @@ FBL.ns(function() { with (FBL) {
 
 const Cc = Components.classes;
 const Ci = Components.interfaces;
+const nsIURI = Ci.nsIURI;
 const nsIDOMCSSStyleRule = Ci.nsIDOMCSSStyleRule;
 const nsIInterfaceRequestor = Ci.nsIInterfaceRequestor;
 const nsISelectionDisplay = Ci.nsISelectionDisplay;
@@ -19,7 +20,7 @@ const STATE_HOVER   = 0x04;
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 
-var domUtils = null;
+const domUtils = CCSV("@mozilla.org/inspector/dom-utils;1", "inIDOMUtils");
 
 var CSSDomplateBase = {
     isEditable: function(rule)
@@ -286,13 +287,15 @@ Firebug.CSSModule = extend(Firebug.Module,
         //
         // WARN: This behavior was determined anecdotally.
         // See http://code.google.com/p/fbug/issues/detail?id=2440
-        var style = doc.createElementNS("http://www.w3.org/1999/xhtml", "style");
-        style.setAttribute("charset","utf-8");
-        unwrapObject(style).firebugIgnore = true;
-        style.setAttribute("type", "text/css");
-        style.innerHTML = "#fbIgnoreStyleDO_NOT_USE {}";
-        addStyleSheet(doc, style);
-        style.parentNode.removeChild(style);
+        if (!isXMLPrettyPrint(doc)) {
+          var style = doc.createElementNS("http://www.w3.org/1999/xhtml", "style");
+          style.setAttribute("charset","utf-8");
+          unwrapObject(style).firebugIgnore = true;
+          style.setAttribute("type", "text/css");
+          style.innerHTML = "#fbIgnoreStyleDO_NOT_USE {}";
+          addStyleSheet(doc, style);
+          style.parentNode.removeChild(style);
+        }
 
         // https://bugzilla.mozilla.org/show_bug.cgi?id=500365
         // This voodoo touches each style sheet to force some Firefox internal change to allow edits.
@@ -728,13 +731,6 @@ Firebug.CSSStyleSheetPanel.prototype = extend(Firebug.SourceBoxPanel,
 
     initialize: function()
     {
-        if (!domUtils)
-        {
-            try {
-                domUtils = CCSV("@mozilla.org/inspector/dom-utils;1", "inIDOMUtils");
-            } catch (exc) {
-            }
-        }
         this.onMouseDown = bind(this.onMouseDown, this);
         this.onClick = bind(this.onClick, this);
 
@@ -810,6 +806,7 @@ Firebug.CSSStyleSheetPanel.prototype = extend(Firebug.SourceBoxPanel,
     {
         if (!styleSheet)
             return;
+
         if (styleSheet.editStyleSheet)
             styleSheet = styleSheet.editStyleSheet.sheet;
 
@@ -824,6 +821,21 @@ Firebug.CSSStyleSheetPanel.prototype = extend(Firebug.SourceBoxPanel,
         this.showToolbarButtons("fbCSSButtons", !isSystemStyleSheet(this.location));
 
         dispatch([Firebug.A11yModel], 'onCSSRulesAdded', [this, this.panelNode]);
+
+        // If the full editing mode (not the inline) is on while the location changes,
+        // open the editor again for another file.
+        if (this.editing && this.stylesheetEditor && this.stylesheetEditor.editing)
+        {
+            // Remove the editing flag to avoid recursion. The StylesheetEditor.endEditing
+            // calls refresh and consequently updateLocation of the CSS panel.
+            this.editing = null;
+
+            // Stop the current editing.
+            Firebug.Editor.stopEditing();
+
+            // ... and open the editor again.
+            this.toggleEditing();
+        }
     },
 
     updateSelection: function(object)
@@ -1515,6 +1527,23 @@ function safeGetContentState(selection)
     }
 }
 
+function isXMLPrettyPrint(doc)
+{
+    try
+    {
+        var bindings = domUtils.getBindingURLs(doc.documentElement);
+        for (var i = 0; i < bindings.length; i++)
+        {
+            var bindingURI = bindings.queryElementAt(i, nsIURI);
+            if (bindingURI.resolve("") === "chrome://global/content/xml/XMLPrettyPrint.xml")
+                return true;
+        }
+    }
+    catch (e)
+    {
+    }
+}
+
 // ************************************************************************************************
 
 function CSSComputedElementPanel() {}
@@ -1851,8 +1880,14 @@ StyleSheetEditor.prototype = domplate(Firebug.BaseEditor,
         Firebug.CSSModule.freeEdit(this.styleSheet, value);
     },
 
+    beginEditing: function()
+    {
+        this.editing = true;
+    },
+
     endEditing: function()
     {
+        this.editing = false;
         this.panel.refresh();
         return true;
     },
