@@ -122,7 +122,7 @@ const DirTablePlate = domplate(Firebug.Rep,
 
     tag:
         TABLE({"class": "domTable", cellpadding: 0, cellspacing: 0, onclick: "$onClick",
-            role: "tree", 'aria-label': $STR('aria.labels.dom properties')},
+            _repObject: "$object", role: "tree", 'aria-label': $STR('aria.labels.dom properties')},
             TBODY({role: 'presentation'},
                 SizerRow,
                 FOR("member", "$object|memberIterator",
@@ -178,6 +178,7 @@ const DirTablePlate = domplate(Firebug.Rep,
         {
             var row = label.parentNode.parentNode;
             this.toggleRow(row);
+            cancelEvent(event);
         }
         else
         {
@@ -206,9 +207,22 @@ const DirTablePlate = domplate(Firebug.Rep,
     toggleRow: function(row)
     {
         var level = parseInt(row.getAttribute("level"));
-        var toggles = row.parentNode.parentNode.toggles;
+        var table = getAncestorByClass(row, "domTable");
+        var toggles = table.toggles;
+        if (!toggles)
+            toggles = table.repObject.toggles;
 
-        var panel = row.parentNode.parentNode.domPanel;
+        var domPanel = table.domPanel;
+        if (!domPanel)
+        {
+            var panel = Firebug.getElementPanel(row);
+            domPanel = panel.context.getPanel("dom");
+        }
+
+        if (!domPanel)
+            return;
+
+        var context = domPanel.context;
         var target = row.lastChild.firstChild;
         var isString = hasClass(target,"objectBox-string");
 
@@ -218,7 +232,7 @@ const DirTablePlate = domplate(Firebug.Rep,
 
             if (isString)
             {
-                var rowValue = panel.getRowPropertyValue(row);
+                var rowValue = domPanel.getRowPropertyValue(row);
                 row.lastChild.firstChild.textContent = '"' + cropMultipleLines(rowValue) + '"';
             }
             else
@@ -257,7 +271,7 @@ const DirTablePlate = domplate(Firebug.Rep,
             setClass(row, "opened");
             if (isString)
             {
-                var rowValue = panel.getRowPropertyValue(row);
+                var rowValue = domPanel.getRowPropertyValue(row);
                 row.lastChild.firstChild.textContent = '"' + rowValue + '"';
             }
             else
@@ -278,8 +292,7 @@ const DirTablePlate = domplate(Firebug.Rep,
                     }
                 }
 
-                var context = panel ? panel.context : null;
-                var members = Firebug.DOMBasePanel.prototype.getMembers(target.repObject, level+1, context);
+                var members = domPanel.getMembers(target.repObject, level+1, context);
 
                 var rowTag = this.rowTag;
                 var lastRow = row;
@@ -363,6 +376,7 @@ Firebug.DOMBasePanel.prototype = extend(Firebug.ActivablePanel,
 
         this.showMembers(members, update, scrollTop);
     },
+
     /*
      *  @param object a user-level object wrapped in security blanket
      *  @param level for a.b.c, level is 2
@@ -582,7 +596,7 @@ Firebug.DOMBasePanel.prototype = extend(Firebug.ActivablePanel,
         FirebugReps.Warning.tag.replace({object: "NoMembersWarning"}, this.panelNode);
     },
 
-    findPathObject: function(object)
+    findPathIndex: function(object)
     {
         var pathIndex = -1;
         for (var i = 0; i < this.objectPath.length; ++i)
@@ -883,7 +897,7 @@ Firebug.DOMBasePanel.prototype = extend(Firebug.ActivablePanel,
         if (view && this.panelNode.scrollTop)
             view.scrollTop = this.panelNode.scrollTop;
 
-        if (this.pathIndex)
+        if (this.pathIndex > -1)
             state.pathIndex = this.pathIndex;
         if (this.viewPath)
             state.viewPath = this.viewPath;
@@ -905,6 +919,8 @@ Firebug.DOMBasePanel.prototype = extend(Firebug.ActivablePanel,
                 this.select(null);
                 return;
             }
+            if (state.pathIndex > -1)
+                this.pathIndex = state.pathIndex;
             if (state.viewPath)
                 this.viewPath = state.viewPath;
             if (state.propertyPath)
@@ -928,8 +944,10 @@ Firebug.DOMBasePanel.prototype = extend(Firebug.ActivablePanel,
 
             if (this.propertyPath.length > 1)
                 selectObject = this.resetPaths(selectObject);
+            else
+                this.propertyPath.push(null);   // Sync with objectPath always containing a defalt object.
 
-            var selection = state.pathIndex <= this.objectPath.length-1
+            var selection = state.pathIndex < this.objectPath.length
                 ? this.getPathObject(state.pathIndex)
                 : this.getPathObject(this.objectPath.length-1);
 
@@ -1010,7 +1028,7 @@ Firebug.DOMBasePanel.prototype = extend(Firebug.ActivablePanel,
         var newPath = this.pathToAppend;
         delete this.pathToAppend;
 
-        var pathIndex = this.findPathObject(object);
+        var pathIndex = this.findPathIndex(object);
         if (newPath || pathIndex == -1)
         {
             this.toggles = {};
@@ -1058,7 +1076,7 @@ Firebug.DOMBasePanel.prototype = extend(Firebug.ActivablePanel,
             {
                 this.toggles = {};
 
-                var win = this.context.getGlobalScope();
+                var win = unwrapObject(this.context.getGlobalScope());
                 if (object == win)
                 {
                     this.pathIndex = 0;
@@ -1104,7 +1122,7 @@ Firebug.DOMBasePanel.prototype = extend(Firebug.ActivablePanel,
 
     getDefaultSelection: function()
     {
-        return this.context.getGlobalScope();
+        return unwrapObject(this.context.getGlobalScope());
     },
 
     updateOption: function(name, value)
