@@ -49,10 +49,10 @@ const firebugURLs =
 {
     main: "http://www.getfirebug.com",
     docs: "http://www.getfirebug.com/docs.html",
-    keyboard: "http://www.getfirebug.com/keyboard.html",
+    keyboard: "http://getfirebug.com/wiki/index.php/Keyboard_and_Mouse_Shortcuts",
     discuss: "http://groups.google.com/group/firebug",
     issues: "http://code.google.com/p/fbug/issues/list",
-    donate: "http://www.getfirebug.com/contribute.html?product"
+    donate: "http://getfirebug.com/getinvolved"
 };
 
 const prefNames =  // XXXjjb TODO distribute to modules
@@ -60,7 +60,8 @@ const prefNames =  // XXXjjb TODO distribute to modules
     // Global
     "defaultPanelName", "throttleMessages", "textSize", "showInfoTips",
     "largeCommandLine", "textWrapWidth", "openInWindow", "showErrorCount",
-    "activateSameOrigin", "allPagesActivation",
+    "activateSameOrigin", "allPagesActivation", "hiddenPanels",
+    "panelTabMinWidth", "sourceLinkLabelWidth",
 
     // Search
     "searchCaseSensitive", "searchGlobal", "netSearchHeaders", "netSearchParameters",
@@ -95,6 +96,7 @@ const prefNames =  // XXXjjb TODO distribute to modules
     // Net
     "netFilterCategory", "collectHttpHeaders", "netDisplayedResponseLimit",
     "netDisplayedPostBodyLimit", "netPhaseInterval", "sizePrecision",
+    "netParamNameLimit",
 
     // Stack
     "omitObjectPathStack",
@@ -1708,7 +1710,10 @@ top.Firebug =
         dispatch(modules, "destroyContext", [context, persistedState]);
 
         if (FirebugContext == context)
+        {
+            Firebug.chrome.clearPanels(); // disconnect the to-be-destroyed panels from the panelBar
             Firebug.chrome.setFirebugContext(null);  // FirebugContext is about to be destroyed
+        }
 
         var browser = context.browser;
         // Persist remnants of the context for restoration if the user reloads
@@ -2782,7 +2787,7 @@ Firebug.DisabledPanelPage.prototype = domplate(Firebug.Rep,
                 SPAN("$pageTitle")
             ),
             P({"class": "disabledPanelDescription", style: "margin-top: 15px;"},
-                $STR("moduleManager.desc4"),
+                $STR("moduleManager.desc3"),
                 SPAN("&nbsp;"),
                 SPAN({"class": "descImage descImage-$panelName"})
             )
