@@ -123,8 +123,8 @@ Firebug.Inspector = extend(Firebug.Module,
         if (node && node.nodeType != 1)
             node = node.parentNode;
 
-        if (node && node.firebugIgnore && !node.fbProxyFor)
-            return;
+        if(node && unwrapObject(node).firebugIgnore && !node.fbProxyFor)
+                return;
 
         var context = this.inspectingContext;
 
@@ -191,7 +191,7 @@ Firebug.Inspector = extend(Firebug.Module,
         Firebug.toggleBar(true);
         Firebug.chrome.select(elt, "html");
         context = this.inspectingContext || TabWatcher.getContextByWindow(elt.ownerDocument.defaultView);
-        htmlPanel = Firebug.chrome.unswitchToPanel(context, "html", false);
+        htmlPanel = Firebug.chrome.selectPanel("html");
         htmlPanel.panelNode.focus();
     },
     
@@ -811,7 +811,6 @@ Firebug.Inspector.FrameHighlighter.prototype =
             return;
 
         var offset = getLTRBWH(element);
-        offset = applyBodyOffsets(element, offset);
         var x = offset.left, y = offset.top;
         var w = offset.width, h = offset.height;
         var wacked = isNaN(x) || isNaN(y) || isNaN(w) || isNaN(h);
@@ -967,7 +966,6 @@ BoxModelHighlighter.prototype =
             var styles = readBoxStyles(style);
 
             var offset = getLTRBWH(element);
-            offset = applyBodyOffsets(element, offset);
 
             var x = offset.left - Math.abs(styles.marginLeft);
             var y = offset.top - Math.abs(styles.marginTop);
@@ -1162,9 +1160,8 @@ BoxModelHighlighter.prototype =
     {
         var parentStyle = win.getComputedStyle(offsetParent, "");
         var parentOffset = getLTRBWH(offsetParent);
-        parentOffset = applyBodyOffsets(offsetParent, parentOffset);
-        var parentX = parentOffset.left + parseInt(parentStyle.borderLeftWidth);
-        var parentY = parentOffset.top + parseInt(parentStyle.borderTopWidth);
+        var parentX = parentOffset.left + parseInt(parentStyle.borderLeftWidth, 10);
+        var parentY = parentOffset.top + parseInt(parentStyle.borderTopWidth, 10);
         var parentW = offsetParent.offsetWidth-1;
         var parentH = offsetParent.offsetHeight-1;
 
