@@ -432,7 +432,6 @@ this.Obj = domplate(Firebug.Rep,
     }
 });
 
-
 // ************************************************************************************************
 
 this.Arr = domplate(Firebug.Rep,
@@ -919,6 +918,26 @@ this.TextNode = domplate(Firebug.Rep,
     }
 });
 
+
+// ************************************************************************************************
+
+var regexpConstructorRE = /RegExp/;
+this.RegExp = domplate(Firebug.Rep,
+{
+    tag:
+        OBJECTLINK(
+            SPAN({"class": "objectTitle"}, "$object|getTitle")
+        ),
+    
+    className: "regexp",
+    
+    supportsObject: function(object, type)
+    {
+        return type == "object" && object && object.constructor && object.constructor.toString && regexpConstructorRE.test(object.constructor.toString());
+    }
+});
+
+
 // ************************************************************************************************
 
 this.Document = domplate(Firebug.Rep,
@@ -1145,7 +1164,18 @@ this.SourceLink = domplate(Firebug.Rep,
 
     hideSourceLink: function(sourceLink)
     {
-        return sourceLink ? sourceLink.href.indexOf("XPCSafeJSObjectWrapper") != -1 : true;
+        try
+        {
+            return (sourceLink && sourceLink.href && sourceLink.href.indexOf) ?
+                (sourceLink.href.indexOf("XPCSafeJSObjectWrapper") != -1) : true;
+        }
+        catch (e)
+        {
+            // xxxHonza: I see "Security error" code: "1000" nsresult: "0x805303e8 (NS_ERROR_DOM_SECURITY_ERR)"
+            // when accessing globalStorage property of a page.
+        }
+
+        return true;
     },
 
     getSourceLinkTitle: function(sourceLink)
@@ -1157,12 +1187,16 @@ this.SourceLink = domplate(Firebug.Rep,
         {
             var fileName = getFileName(sourceLink.href);
             fileName = decodeURIComponent(fileName);
-            fileName = cropString(fileName, 17);
         }
         catch(exc)
         {
             fileName = sourceLink.href;
         }
+
+        var maxWidth = Firebug.sourceLinkLabelWidth;
+        if (maxWidth > 0)
+            fileName = cropString(fileName, maxWidth);
+
         if (sourceLink.instance)
             return $STRF("InstanceLine", [fileName, sourceLink.instance+1, sourceLink.line]);
         else if (sourceLink.line)
@@ -1200,7 +1234,23 @@ this.SourceLink = domplate(Firebug.Rep,
 
     getTooltip: function(sourceLink)
     {
-        return decodeURI(sourceLink.href);
+        var text;
+        try
+        {
+            text = decodeURI(sourceLink.href);
+        }
+        catch(exc)
+        {
+        }
+
+        text = unescape(sourceLink.href);
+
+        var lines = splitLines(text);
+        if (lines.length < 10)
+            return text;
+
+        lines.splice(10);
+        return lines.join("") + "...";
     },
 
     inspectObject: function(sourceLink, context)
@@ -1465,6 +1515,7 @@ this.ErrorMessage = domplate(Firebug.Rep,
                 "$object.message|getMessage"
             ),
             DIV({"class": "errorTrace", role : 'presentation'}),
+            TAG("$object|getObjectsTag", {object: "$object.objects"}),
             DIV({"class": "errorSourceBox errorSource-$object|getSourceType focusRow subLogRow", role : "listitem"},
                 IMG({"class": "errorBreak a11yFocus", src:"blank.gif", role : 'checkbox', 'aria-checked':"$object|hasErrorBreak", title: "Break on this error"}),
                 A({"class": "errorSource a11yFocus"}, "$object|getLine"),
@@ -1472,6 +1523,11 @@ this.ErrorMessage = domplate(Firebug.Rep,
             )
         ),
 
+    getObjectsTag: function(error)
+    {
+        return error.objects ? FirebugReps.Arr.tag : SPAN();
+    },
+
     getLastErrorStackTrace: function(error)
     {
         return error.trace;
@@ -1823,6 +1879,7 @@ Firebug.registerRep(
     this.Undefined,
     this.Null,
     this.Number,
+    this.RegExp,
     this.String,
     this.Window,
     this.ApplicationCache, // must come before Arr (array) else exceptions.
