@@ -54,7 +54,8 @@ var contentTypes =
     "application/json": 1,
     "application/x-js": 1,
     "multipart/mixed" : 1,
-    "multipart/x-mixed-replace" : 1
+    "multipart/x-mixed-replace" : 1,
+    "image/svg+xml" : 1
 };
 
 // ************************************************************************************************
@@ -176,7 +177,11 @@ Firebug.TabCacheModel = extend(Firebug.Module,
                 // The response will be written into the outputStream of this pipe.
                 // Both ends of the pipe must be blocking.
                 var sink = CCIN("@mozilla.org/pipe;1", "nsIPipe");
-                sink.init(true, true, 0, 0, null);
+                sink.init(false, false, 0x20000, 0x4000, null);
+
+                // Remember the input stream, so it isn't released by GC.
+                // See issue 2788 for more details.
+                newListener.wrappedJSObject.inputStream = sink.inputStream;
 
                 var originalListener = request.setNewListener(tee);
                 newListener.wrappedJSObject.sink = sink;
