@@ -92,17 +92,6 @@ top.TabWatcher = extend(new Firebug.Listener(),
         }
 
         var selectedBrowser = Firebug.chrome.getCurrentBrowser();
-        if (selectedBrowser.cancelNextLoad)
-        {
-            // We need to cancel this load and try again after a delay... this is used
-            // mainly to prevent chaos while when the debugger is active when a page
-            // is unloaded
-            delete selectedBrowser.cancelNextLoad;
-            selectedBrowser.webNavigation.stop(STOP_ALL);
-            var url = (uri instanceof nsIURI?uri.spec:uri);
-            delayBrowserLoad(selectedBrowser, url);
-            return;
-        }
 
         var context = this.getContextByWindow(win);
         if (context) // then we've looked at this window before in this FF session...
@@ -114,10 +103,6 @@ top.TabWatcher = extend(new Firebug.Listener(),
                     delete context.browser.showFirebug;
                 this.unwatchContext(win, context);
 
-                // There shouldn't be context for this window so, remove it from the
-                // global array.
-                remove(contexts, context);
-
                 return;  // did not create a context
             }
             // else we should show
@@ -300,6 +285,11 @@ top.TabWatcher = extend(new Firebug.Listener(),
 
         var location = safeGetWindowLocation(win);
 
+        // For every window we watch, prepare for unwatch. It's OK if this is called
+        // more times (see 2695).
+        if (context && location != aboutBlank)
+            TabWatcherUnloader.registerWindow(win);
+
         // Unfortunately, dummy requests that trigger the call to watchWindow
         // are called several times, so we have to avoid dispatching watchWindow
         // more than once
@@ -307,15 +297,6 @@ top.TabWatcher = extend(new Firebug.Listener(),
         {
             context.windows.push(win);
 
-            if (win.parent == win)
-            {
-                win.addEventListener("pagehide", onPageHideTopWindow, false);
-            }
-            else
-            {
-                win.addEventListener("unload", onUnloadWindow, false);
-            }
-
             dispatch(this.fbListeners, "watchWindow", [context, win]);
 
         }
@@ -429,15 +410,12 @@ top.TabWatcher = extend(new Firebug.Listener(),
 
         dispatch(this.fbListeners, "destroyContext", [context, persistedState, context.browser]);
 
-        if (this.cancelNextLoad)
-        {
-            delete this.cancelNextLoad;
-            context.browser.cancelNextLoad = true;
-        }
-
         context.destroy(persistedState);
         remove(contexts, context);
 
+        for (var name in context)
+            delete context[name];
+
         var currentBrowser = Firebug.chrome.getCurrentBrowser();
         if (!currentBrowser.showFirebug)  // unwatchContext can be called on an unload event after another tab is selected
             dispatch(this.fbListeners, "showContext", [browser, null]); // context is null if we don't want to debug this browser
@@ -515,6 +493,57 @@ top.TabWatcher = extend(new Firebug.Listener(),
 
 // ************************************************************************************************
 
+var TabWatcherUnloader =
+{
+    listeners: [],
+
+    registerWindow: function(win)
+    {
+        var root = (win.parent == win);
+        var eventName = root ? "pagehide" : "unload";
+        var listener = bind(root ? this.onPageHide : this.onUnload, this);
+        win.addEventListener(eventName, listener, false);
+
+        this.listeners.push({
+            window: win,
+            listener: listener,
+            eventName: eventName
+        });
+    },
+
+    unregisterWindow: function(win)
+    {
+        var newListeners = [];
+        for (var i=0; i<this.listeners.length; i++)
+        {
+            var listener = this.listeners[i];
+            if (listener.window != win)
+                newListeners.push(listener);
+            else
+                win.removeEventListener(listener.eventName, listener.listener, false);
+        }
+        this.listeners = newListeners;
+    },
+
+    onPageHide: function(event)
+    {
+        var win = event.currentTarget;
+        this.unregisterWindow(win);
+
+        onPageHideTopWindow(event);
+    },
+
+    onUnload: function(event)
+    {
+        var win = event.currentTarget;
+        this.unregisterWindow(win);
+
+        onUnloadWindow(event);
+    }
+};
+
+// ************************************************************************************************
+
 var TabProgressListener = extend(BaseProgressListener,
 {
     onLocationChange: function(progress, request, uri)
@@ -707,9 +736,6 @@ function onPageHideTopWindow(event)
     if (doc.defaultView != win)
         return; // ignore page hides on interior windows
 
-    win.removeEventListener("pagehide", onPageHideTopWindow, false);
-
-    // http://developer.mozilla.org/en/docs/Using_Firefox_1.5_caching#pagehide_event
     if (event.persisted) // then the page is cached and there cannot be an unload handler
     {
         //  see Bug 484710 -  add pageIgnore event for pages that are ejected from the bfcache
@@ -774,18 +800,9 @@ function onUnloadWindow(event)
 {
     var win = event.currentTarget;
     var eventType = "unload";
-    win.removeEventListener(eventType, onUnloadWindow, false);
     TabWatcher.unwatchWindow(win);
 }
 
-function delayBrowserLoad(browser, uri)
-{
-    setTimeout(function delayBrowserLoad100()
-    {
-        browser.loadURI(uri);
-    }, 100);
-}
-
 function safeGetName(request)
 {
     try
